-- ******************************* --
-- * Frames for SuperGuildInvite * --
-- *		 Written by          * --
-- *   Janniie - Stormreaver EU  * --
-- ******************************* --



--***********************--
--* Imported functions *--
--***********************--

local SetSavedFramePos = SuperGuildInviteGeneral.SetSavedFramePos
local SaveCurFramePos  = SuperGuildInviteGeneral.SaveCurFramePos
local UpdateOptBtn     = SuperGuildInviteGeneral.UpdateOptBtn

local function HideOptions()
    local inFrame = SuperGuildInviteOptions["TheOptionsFrame"]
	if inFrame then inFrame:Hide() end
end	

local function HideQuestion()
	local Question = SuperGuildInviteOptions["TheQuestion"]
	if Question then Question:Hide() end
end


-- *************************** --
-- *  1. Frame for Options   * --
-- *************************** --


local function CreateOptionsFrame(version)

	local OptionsFrame = CreateFrame("Frame","SuperGuildInvite",UIParent)
	OptionsFrame:SetHeight(200)
	OptionsFrame:SetWidth(500)
	SetSavedFramePos(OptionsFrame)
	
	OptionsFrame:SetMovable()
	OptionsFrame:RegisterForDrag("LeftButton","RightButton")
	OptionsFrame:SetScript("OnMouseDown",function(self)
		self:StartMoving()
	end)
	OptionsFrame:SetScript("OnMouseUp",function(self)
		self:StopMovingOrSizing()
		SaveCurFramePos(OptionsFrame)
	end)
	
	local backdrop = 
	{
		bgFile = "Interface\\DialogFrame\\UI-DialogBox-Gold-Background", 
		edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Gold-Border", 
		tile = true,
		tileSize = 16,
		edgeSize = 16,
		insets = { left = 4, right = 4, top = 4, bottom = 4 }
	}
	OptionsFrame:SetBackdrop(backdrop)
	
	local TitleFont = OptionsFrame:CreateFontString(nil,"OVERLAY","GameFontNormalLarge")
	TitleFont:SetText("SuperGuildInvite "..version.." Options")
	TitleFont:SetPoint("TOP",OptionsFrame,"TOP",0,-20)
	
	local BottomFont = OptionsFrame:CreateFontString(nil,"OVERLAY","GameFontNormalLarge")
	BottomFont:SetText("Written by Janniie - Stormreaver EU")
	BottomFont:SetPoint("BOTTOM",OptionsFrame,"BOTTOM",0,20)
	OptionsFrame:Hide()
	SuperGuildInviteOptions["TheOptionsFrame"] = OptionsFrame
	
	-- Option button 1 --
	local OptBtn1 = CreateFrame("Button","OptBtn1",OptionsFrame)
	OptBtn1:SetHeight(40)
	OptBtn1:SetWidth(220)
	OptBtn1:SetPoint("TOP",OptionsFrame,"TOP",-120,-50)
	OptBtn1:SetBackdrop(backdrop)
	
	local OptFont1 = OptBtn1:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont1:SetText("Enable SuperGuildInvite")
	OptFont1:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn1"] then
		OptFont1:SetTextColor(0,1,0)
	else
		OptFont1:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn1:GetName()] = OptFont1
	
	OptBtn1:SetScript("OnClick",UpdateOptBtn)
	
	-- Option button 2 --
	local OptBtn2 = CreateFrame("Button","OptBtn2",OptionsFrame)
	OptBtn2:SetHeight(40)
	OptBtn2:SetWidth(220)
	OptBtn2:SetPoint("TOP",OptionsFrame,"TOP",120,-50)
	OptBtn2:SetBackdrop(backdrop)
	
	local OptFont2 = OptBtn2:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont2:SetText("Send a whisper before inviting")
	OptFont2:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn2"] then
		OptFont2:SetTextColor(0,1,0)
	else
		OptFont2:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn2:GetName()] = OptFont2
	
	OptBtn2:SetScript("OnClick",UpdateOptBtn)
	
	-- Option button 3 --
	local OptBtn3 = CreateFrame("Button","OptBtn3",OptionsFrame)
	OptBtn3:SetHeight(40)
	OptBtn3:SetWidth(220)
	OptBtn3:SetPoint("TOP",OptionsFrame,"TOP",-120,-105)
	OptBtn3:SetBackdrop(backdrop)
	
	local OptFont3 = OptBtn3:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont3:SetText("Auto-close after Who search")
	OptFont3:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn3"] then
		OptFont3:SetTextColor(0,1,0)
	else
		OptFont3:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn3:GetName()] = OptFont3
	
	OptBtn3:SetScript("OnClick",UpdateOptBtn)
	
	-- Option button 4 --
	local OptBtn4 = CreateFrame("Button","OptBtn4",OptionsFrame)
	OptBtn4:SetHeight(40)
	OptBtn4:SetWidth(220)
	OptBtn4:SetPoint("TOP",OptionsFrame,"TOP",120,-105)
	OptBtn4:SetBackdrop(backdrop)
	
	local OptFont4 = OptBtn4:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont4:SetPoint("CENTER")
	if SuperGuildInviteOptions["HourOptBtn4"] == 1 then
		OptFont4:SetTextColor(0.2,0.7,0.5)
		OptFont4:SetText("Reinvite lockout: 24 hours")
	elseif SuperGuildInviteOptions["HourOptBtn4"] == 2 then
		OptFont4:SetTextColor(0.7,0.23,0.93)
		OptFont4:SetText("Reinvite lockout: 48 hours")
	else
		OptFont4:SetText("Reinvite lockout: 72 hours")
		OptFont4:SetTextColor(0.5,1,1)
	end
	SuperGuildInviteOptions["Font"..OptBtn4:GetName()] = OptFont4
	
	OptBtn4:SetScript("OnClick",UpdateOptBtn)
	-- Option button 5 --
	--[[local OptBtn5 = CreateFrame("Button","OptBtn5",OptionsFrame)
	OptBtn5:SetHeight(40)
	OptBtn5:SetWidth(220)
	OptBtn5:SetPoint("TOP",OptionsFrame,"TOP",-120,-160)
	OptBtn5:SetBackdrop(backdrop)
	
	local OptFont5 = OptBtn5:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont5:SetText("Option Five")
	OptFont5:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn5"] then
		OptFont5:SetTextColor(0,1,0)
	else
		OptFont5:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn5:GetName()] = OptFont5
	
	OptBtn5:SetScript("OnClick",UpdateOptBtn)
	
	-- Option button 6 --
	local OptBtn6 = CreateFrame("Button","OptBtn6",OptionsFrame)
	OptBtn6:SetHeight(40)
	OptBtn6:SetWidth(220)
	OptBtn6:SetPoint("TOP",OptionsFrame,"TOP",120,-160)
	OptBtn6:SetBackdrop(backdrop)
	
	local OptFont6 = OptBtn6:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont6:SetText("Option Six")
	OptFont6:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn6"] then
		OptFont6:SetTextColor(0,1,0)
	else
		OptFont6:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn6:GetName()] = OptFont6
	
	OptBtn6:SetScript("OnClick",UpdateOptBtn)
	
	-- Option button 7 --
	local OptBtn7 = CreateFrame("Button","OptBtn7",OptionsFrame)
	OptBtn7:SetHeight(40)
	OptBtn7:SetWidth(220)
	OptBtn7:SetPoint("TOP",OptionsFrame,"TOP",-120,-215)
	OptBtn7:SetBackdrop(backdrop)
	
	local OptFont7 = OptBtn7:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont7:SetText("Option Seven")
	OptFont7:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn7"] then
		OptFont7:SetTextColor(0,1,0)
	else
		OptFont7:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn7:GetName()] = OptFont7
	
	OptBtn7:SetScript("OnClick",UpdateOptBtn)
	
	-- Option button 8 --
	local OptBtn8 = CreateFrame("Button","OptBtn8",OptionsFrame)
	OptBtn8:SetHeight(40)
	OptBtn8:SetWidth(220)
	OptBtn8:SetPoint("TOP",OptionsFrame,"TOP",120,-215)
	OptBtn8:SetBackdrop(backdrop)
	
	local OptFont8 = OptBtn8:CreateFontString(nil,"OVERLAY","GameFontNormal")
	OptFont8:SetText("Option Eight")
	OptFont8:SetPoint("CENTER")
	if SuperGuildInviteOptions["OptBtn8"] then
		OptFont8:SetTextColor(0,1,0)
	else
		OptFont8:SetTextColor(1,0,0)
	end
	SuperGuildInviteOptions["Font"..OptBtn8:GetName()] = OptFont8
	
	OptBtn8:SetScript("OnClick",UpdateOptBtn)
	
	]]
	-- Close button --
	
	local CloseBtn = CreateFrame("Button","CloseBtn",OptionsFrame)
	CloseBtn:SetHeight(35)
	CloseBtn:SetWidth(35)
	CloseBtn:SetPoint("TOPRIGHT",OptionsFrame,"TOPRIGHT",-5,-5)
	CloseBtn:SetBackdrop(backdrop)
	CloseBtn:RegisterForClicks("LeftButtonDown")
	CloseBtn:SetScript("OnClick",HideOptions)
	local CloseBtnF = CloseBtn:CreateFontString(nil,"OVERLAY","GameFontNormal")
	CloseBtnF:SetText("X")
	CloseBtnF:SetTextColor(1,0,0)
	CloseBtnF:SetPoint("CENTER")
	
	
	return OptionsFrame,OptBtn1,OptBtn2,OptBtn3,OptBtn4,OptBtn5,OptBtn6,OptBtn7,OptBtn8
	
	
end


--Question frame--
local function CreateQuestion()
	local frame = CreateFrame("Frame")
	frame:SetHeight(150)
	frame:SetWidth(400)
	frame:SetPoint("CENTER")
	
	
	local backdrop = 
	{
		bgFile = "Interface\\DialogFrame\\UI-DialogBox-Gold-Background", 
		edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Gold-Border", 
		tile = true,
		tileSize = 16,
		edgeSize = 16,
		insets = { left = 4, right = 4, top = 4, bottom = 4 }
	}
	frame:SetBackdrop(backdrop)
	local QFont = frame:CreateFontString(nil,"OVERLAY","GameFontNormalLarge")
	QFont:SetText("SuperGuildInvite")
	QFont:SetPoint("TOP",frame,"TOP",0,-20)
	
	local Qfont = frame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	Qfont:SetText("Do you miss a certain Option?\nDid you find a bug?\nDo you have a suggestion for a new feature?\n\nVisit www.Curse.com and leave a comment!")
	Qfont:SetPoint("CENTER",frame,0,-10)
	frame:Hide()
	
	local CloseBtn = CreateFrame("Button","CloseBtn",frame)
	CloseBtn:SetHeight(35)
	CloseBtn:SetWidth(35)
	CloseBtn:SetPoint("TOPRIGHT",frame,"TOPRIGHT",-5,-5)
	CloseBtn:SetBackdrop(backdrop)
	CloseBtn:RegisterForClicks("LeftButtonDown")
	CloseBtn:SetScript("OnClick",HideQuestion)
	local CloseBtnF = CloseBtn:CreateFontString(nil,"OVERLAY","GameFontNormal")
	CloseBtnF:SetText("X")
	CloseBtnF:SetTextColor(1,0,0)
	CloseBtnF:SetPoint("CENTER")
	
	SuperGuildInviteOptions["TheQuestion"] = frame
	return frame
end
--*******************--
--* Frame functions *--
--*******************--
local function ShowOptions(frame,version)
	if not frame then frame,OptBtn1,OptBtn2,OptBtn3,OptBtn4,OptBtn5,OptBtn6,OptBtn7,OptBtn8 = CreateOptionsFrame(version) end
	if not frame:IsShown() then frame:Show() end
	return frame,OptBtn1,OptBtn2,OptBtn3,OptBtn4,OptBtn5,OptBtn6,OptBtn7,OptBtn8
end

local function ShowQuestion(frame)
	if not frame then frame = CreateQuestion() end
	if not frame:IsShown() then frame:Show() end
end


SuperGuildInviteGeneral.ShowQuestion = ShowQuestion
SuperGuildInviteGeneral.HideQuestion = HideQuestion
SuperGuildInviteGeneral.ShowOptions  = ShowOptions
SuperGuildInviteGeneral.HideOptions  = HideOptions